@@ -1,4 +1,4 @@
-from rankset.common.my_sql import MySqlConnection
+from rr.my_sql import MySqlConnection
 from rr_batch import constants, sql
 from rr_batch import process
 
